@@ -68,7 +68,7 @@ private Q_SLOTS:
         fakeServer.setScenario(scenario);
         fakeServer.startAndWait();
 
-        KIMAP::Session session(QLatin1String("127.0.0.1"), 5989);
+        KIMAP::Session session(QStringLiteral("127.0.0.1"), 5989);
 
         KIMAP::RenameJob *job = new KIMAP::RenameJob(&session);
         job->setSourceMailBox(mailbox);
